Module host
hyperlight_
js_
runtime
0.1.0
Module host
Module Items
Traits
In crate hyperlight_
js_
runtime
hyperlight_js_runtime
Module
host
Traits

Host
A trait representing the host environment for the JS runtime. In hyperlight this would represent the host function calls that the runtime needs.